@@ -1,22 +1,22 @@
 from django import forms
 
-from nautobot.dcim.models import Region, Site
+from nautobot.dcim.form_mixins import (
+    LocatableModelFilterFormMixin,
+    LocatableModelFormMixin,
+)
 from nautobot.extras.forms import (
-    AddRemoveTagsForm,
-    CustomFieldBulkEditForm,
-    CustomFieldFilterForm,
-    CustomFieldModelForm,
     CustomFieldModelCSVForm,
-    RelationshipModelForm,
-    StatusBulkEditFormMixin,
+    NautobotFilterForm,
+    NautobotBulkEditForm,
+    NautobotModelForm,
+    StatusModelBulkEditFormMixin,
     StatusModelCSVFormMixin,
-    StatusFilterFormMixin,
+    StatusModelFilterFormMixin,
+    TagsBulkEditFormMixin,
 )
-from nautobot.extras.models import Tag
 from nautobot.tenancy.forms import TenancyFilterForm, TenancyForm
 from nautobot.tenancy.models import Tenant
 from nautobot.utilities.forms import (
-    BootstrapMixin,
     CommentField,
     CSVModelChoiceField,
     DatePicker,
@@ -26,7 +26,7 @@ from nautobot.utilities.forms import (
     SlugField,
     TagFilterField,
 )
-from .models import Circuit, CircuitTermination, CircuitType, Provider
+from .models import Circuit, CircuitTermination, CircuitType, Provider, ProviderNetwork
 
 
 #
@@ -34,10 +34,9 @@ from .models import Circuit, CircuitTermination, CircuitType, Provider
 #
 
 
-class ProviderForm(BootstrapMixin, CustomFieldModelForm, RelationshipModelForm):
+class ProviderForm(NautobotModelForm):
     slug = SlugField()
     comments = CommentField()
-    tags = DynamicModelMultipleChoiceField(queryset=Tag.objects.all(), required=False)
 
     class Meta:
         model = Provider
@@ -71,10 +70,10 @@ class ProviderCSVForm(CustomFieldModelCSVForm):
         fields = Provider.csv_headers
 
 
-class ProviderBulkEditForm(BootstrapMixin, AddRemoveTagsForm, CustomFieldBulkEditForm):
+class ProviderBulkEditForm(TagsBulkEditFormMixin, NautobotBulkEditForm):
     pk = forms.ModelMultipleChoiceField(queryset=Provider.objects.all(), widget=forms.MultipleHiddenInput)
     asn = forms.IntegerField(required=False, label="ASN")
-    account = forms.CharField(max_length=30, required=False, label="Account number")
+    account = forms.CharField(max_length=100, required=False, label="Account number")
     portal_url = forms.URLField(required=False, label="Portal")
     noc_contact = forms.CharField(required=False, widget=SmallTextarea, label="NOC contact")
     admin_contact = forms.CharField(required=False, widget=SmallTextarea, label="Admin contact")
@@ -91,26 +90,78 @@ class ProviderBulkEditForm(BootstrapMixin, AddRemoveTagsForm, CustomFieldBulkEdi
         ]
 
 
-class ProviderFilterForm(BootstrapMixin, CustomFieldFilterForm):
+class ProviderFilterForm(NautobotFilterForm, LocatableModelFilterFormMixin):
     model = Provider
+    field_order = ["q"]
     q = forms.CharField(required=False, label="Search")
-    region = DynamicModelMultipleChoiceField(queryset=Region.objects.all(), to_field_name="slug", required=False)
-    site = DynamicModelMultipleChoiceField(
-        queryset=Site.objects.all(),
-        to_field_name="slug",
-        required=False,
-        query_params={"region": "$region"},
-    )
     asn = forms.IntegerField(required=False, label="ASN")
     tag = TagFilterField(model)
 
 
+#
+# Provider Networks
+#
+
+
+class ProviderNetworkForm(NautobotModelForm):
+    slug = SlugField()
+    provider = DynamicModelChoiceField(queryset=Provider.objects.all())
+    comments = CommentField(label="Comments")
+
+    class Meta:
+        model = ProviderNetwork
+        fields = [
+            "provider",
+            "name",
+            "slug",
+            "description",
+            "comments",
+            "tags",
+        ]
+        fieldsets = (("Provider Network", ("provider", "name", "slug", "description", "comments", "tags")),)
+
+
+class ProviderNetworkCSVForm(CustomFieldModelCSVForm):
+    provider = CSVModelChoiceField(queryset=Provider.objects.all(), to_field_name="name", help_text="Assigned provider")
+
+    class Meta:
+        model = ProviderNetwork
+        fields = [
+            "provider",
+            "name",
+            "slug",
+            "description",
+            "comments",
+        ]
+
+
+class ProviderNetworkBulkEditForm(TagsBulkEditFormMixin, NautobotBulkEditForm):
+    pk = forms.ModelMultipleChoiceField(queryset=ProviderNetwork.objects.all(), widget=forms.MultipleHiddenInput)
+    provider = DynamicModelChoiceField(queryset=Provider.objects.all(), required=False)
+    description = forms.CharField(max_length=100, required=False)
+    comments = CommentField(widget=SmallTextarea, label="Comments")
+
+    class Meta:
+        nullable_fields = [
+            "description",
+            "comments",
+        ]
+
+
+class ProviderNetworkFilterForm(NautobotFilterForm):
+    model = ProviderNetwork
+    field_order = ["q", "provider_id"]
+    q = forms.CharField(required=False, label="Search")
+    provider_id = DynamicModelMultipleChoiceField(queryset=Provider.objects.all(), required=False, label="Provider")
+    tag = TagFilterField(model)
+
+
 #
 # Circuit types
 #
 
 
-class CircuitTypeForm(BootstrapMixin, CustomFieldModelForm, RelationshipModelForm):
+class CircuitTypeForm(NautobotModelForm):
     slug = SlugField()
 
     class Meta:
@@ -136,11 +187,10 @@ class CircuitTypeCSVForm(CustomFieldModelCSVForm):
 #
 
 
-class CircuitForm(BootstrapMixin, TenancyForm, CustomFieldModelForm, RelationshipModelForm):
+class CircuitForm(NautobotModelForm, TenancyForm):
     provider = DynamicModelChoiceField(queryset=Provider.objects.all())
     type = DynamicModelChoiceField(queryset=CircuitType.objects.all())
     comments = CommentField()
-    tags = DynamicModelMultipleChoiceField(queryset=Tag.objects.all(), required=False)
 
     class Meta:
         model = Circuit
@@ -199,7 +249,7 @@ class CircuitCSVForm(StatusModelCSVFormMixin, CustomFieldModelCSVForm):
         ]
 
 
-class CircuitBulkEditForm(BootstrapMixin, AddRemoveTagsForm, StatusBulkEditFormMixin, CustomFieldBulkEditForm):
+class CircuitBulkEditForm(TagsBulkEditFormMixin, StatusModelBulkEditFormMixin, NautobotBulkEditForm):
     pk = forms.ModelMultipleChoiceField(queryset=Circuit.objects.all(), widget=forms.MultipleHiddenInput)
     type = DynamicModelChoiceField(queryset=CircuitType.objects.all(), required=False)
     provider = DynamicModelChoiceField(queryset=Provider.objects.all(), required=False)
@@ -217,15 +267,22 @@ class CircuitBulkEditForm(BootstrapMixin, AddRemoveTagsForm, StatusBulkEditFormM
         ]
 
 
-class CircuitFilterForm(BootstrapMixin, TenancyFilterForm, StatusFilterFormMixin, CustomFieldFilterForm):
+class CircuitFilterForm(
+    NautobotFilterForm,
+    LocatableModelFilterFormMixin,
+    TenancyFilterForm,
+    StatusModelFilterFormMixin,
+):
     model = Circuit
     field_order = [
         "q",
         "type",
         "provider",
+        "provider_network",
         "status",
         "region",
         "site",
+        "location",
         "tenant_group",
         "tenant",
         "commit_rate",
@@ -233,12 +290,11 @@ class CircuitFilterForm(BootstrapMixin, TenancyFilterForm, StatusFilterFormMixin
     q = forms.CharField(required=False, label="Search")
     type = DynamicModelMultipleChoiceField(queryset=CircuitType.objects.all(), to_field_name="slug", required=False)
     provider = DynamicModelMultipleChoiceField(queryset=Provider.objects.all(), to_field_name="slug", required=False)
-    region = DynamicModelMultipleChoiceField(queryset=Region.objects.all(), to_field_name="slug", required=False)
-    site = DynamicModelMultipleChoiceField(
-        queryset=Site.objects.all(),
-        to_field_name="slug",
+    provider_network = DynamicModelMultipleChoiceField(
+        queryset=ProviderNetwork.objects.all(),
         required=False,
-        query_params={"region": "$region"},
+        query_params={"provider_id": "$provider"},
+        label="Provider Network",
     )
     commit_rate = forms.IntegerField(required=False, min_value=0, label="Commit rate (Kbps)")
     tag = TagFilterField(model)
@@ -249,9 +305,10 @@ class CircuitFilterForm(BootstrapMixin, TenancyFilterForm, StatusFilterFormMixin
 #
 
 
-class CircuitTerminationForm(BootstrapMixin, RelationshipModelForm):
-    region = DynamicModelChoiceField(queryset=Region.objects.all(), required=False, initial_params={"sites": "$site"})
-    site = DynamicModelChoiceField(queryset=Site.objects.all(), query_params={"region_id": "$region"})
+class CircuitTerminationForm(LocatableModelFormMixin, NautobotModelForm):
+    provider_network = DynamicModelChoiceField(
+        queryset=ProviderNetwork.objects.all(), required=False, label="Provider Network"
+    )
 
     class Meta:
         model = CircuitTermination
@@ -259,11 +316,14 @@ class CircuitTerminationForm(BootstrapMixin, RelationshipModelForm):
             "term_side",
             "region",
             "site",
+            "location",
+            "provider_network",
             "port_speed",
             "upstream_speed",
             "xconnect_id",
             "pp_info",
             "description",
+            "tags",
         ]
         help_texts = {
             "port_speed": "Physical circuit speed",
