@@ -72,8 +72,9 @@ SEARCH_TYPES = OrderedDict(
         (
             "circuit",
             {
-                # v2 TODO(jathan): Replace prefetch_related with select_related
-                "queryset": Circuit.objects.prefetch_related("type", "provider", "tenant", "terminations__site"),
+                "queryset": Circuit.objects.select_related("type", "provider", "tenant").prefetch_related(
+                    "terminations__site"
+                ),
                 "filterset": CircuitFilterSet,
                 "table": CircuitTable,
                 "url": "circuits:circuit_list",
@@ -82,8 +83,7 @@ SEARCH_TYPES = OrderedDict(
         (
             "providernetwork",
             {
-                # v2 TODO(jathan): Replace prefetch_related with select_related
-                "queryset": ProviderNetwork.objects.prefetch_related("provider"),
+                "queryset": ProviderNetwork.objects.select_related("provider"),
                 "filterset": ProviderNetworkFilterSet,
                 "table": ProviderNetworkTable,
                 "url": "circuits:providernetwork_list",
@@ -93,8 +93,7 @@ SEARCH_TYPES = OrderedDict(
         (
             "site",
             {
-                # v2 TODO(jathan): Replace prefetch_related with select_related
-                "queryset": Site.objects.prefetch_related("region", "tenant"),
+                "queryset": Site.objects.select_related("region", "tenant"),
                 "filterset": SiteFilterSet,
                 "table": SiteTable,
                 "url": "dcim:site_list",
@@ -103,8 +102,7 @@ SEARCH_TYPES = OrderedDict(
         (
             "rack",
             {
-                # v2 TODO(jathan): Replace prefetch_related with select_related
-                "queryset": Rack.objects.prefetch_related("site", "group", "tenant", "role"),
+                "queryset": Rack.objects.select_related("site", "group", "tenant", "role"),
                 "filterset": RackFilterSet,
                 "table": RackTable,
                 "url": "dcim:rack_list",
@@ -113,14 +111,13 @@ SEARCH_TYPES = OrderedDict(
         (
             "rackgroup",
             {
-                # v2 TODO(jathan): Replace prefetch_related with select_related
                 "queryset": RackGroup.objects.add_related_count(
                     RackGroup.objects.all(),
                     Rack,
                     "group",
                     "rack_count",
                     cumulative=True,
-                ).prefetch_related("site"),
+                ).select_related("site"),
                 "filterset": RackGroupFilterSet,
                 "table": RackGroupTable,
                 "url": "dcim:rackgroup_list",
@@ -129,8 +126,7 @@ SEARCH_TYPES = OrderedDict(
         (
             "devicetype",
             {
-                # v2 TODO(jathan): Replace prefetch_related with select_related
-                "queryset": DeviceType.objects.prefetch_related("manufacturer").annotate(
+                "queryset": DeviceType.objects.select_related("manufacturer").annotate(
                     instance_count=count_related(Device, "device_type")
                 ),
                 "filterset": DeviceTypeFilterSet,
@@ -141,8 +137,7 @@ SEARCH_TYPES = OrderedDict(
         (
             "device",
             {
-                # v2 TODO(jathan): Replace prefetch_related with select_related
-                "queryset": Device.objects.prefetch_related(
+                "queryset": Device.objects.select_related(
                     "device_type__manufacturer",
                     "device_role",
                     "tenant",
@@ -159,8 +154,7 @@ SEARCH_TYPES = OrderedDict(
         (
             "virtualchassis",
             {
-                # v2 TODO(jathan): Replace prefetch_related with select_related
-                "queryset": VirtualChassis.objects.prefetch_related("master").annotate(
+                "queryset": VirtualChassis.objects.select_related("master").annotate(
                     member_count=count_related(Device, "virtual_chassis")
                 ),
                 "filterset": VirtualChassisFilterSet,
@@ -190,8 +184,7 @@ SEARCH_TYPES = OrderedDict(
         (
             "cluster",
             {
-                # v2 TODO(jathan): Replace prefetch_related with select_related
-                "queryset": Cluster.objects.prefetch_related("type", "group").annotate(
+                "queryset": Cluster.objects.select_related("type", "group").annotate(
                     device_count=count_related(Device, "cluster"),
                     vm_count=count_related(VirtualMachine, "cluster"),
                 ),
@@ -203,8 +196,7 @@ SEARCH_TYPES = OrderedDict(
         (
             "virtualmachine",
             {
-                # v2 TODO(jathan): Replace prefetch_related with select_related
-                "queryset": VirtualMachine.objects.prefetch_related(
+                "queryset": VirtualMachine.objects.select_related(
                     "cluster",
                     "tenant",
                     "platform",
@@ -220,8 +212,7 @@ SEARCH_TYPES = OrderedDict(
         (
             "vrf",
             {
-                # v2 TODO(jathan): Replace prefetch_related with select_related
-                "queryset": VRF.objects.prefetch_related("tenant"),
+                "queryset": VRF.objects.select_related("tenant"),
                 "filterset": VRFFilterSet,
                 "table": VRFTable,
                 "url": "ipam:vrf_list",
@@ -230,8 +221,7 @@ SEARCH_TYPES = OrderedDict(
         (
             "aggregate",
             {
-                # v2 TODO(jathan): Replace prefetch_related with select_related
-                "queryset": Aggregate.objects.prefetch_related("rir"),
+                "queryset": Aggregate.objects.select_related("rir"),
                 "filterset": AggregateFilterSet,
                 "table": AggregateTable,
                 "url": "ipam:aggregate_list",
@@ -240,8 +230,7 @@ SEARCH_TYPES = OrderedDict(
         (
             "prefix",
             {
-                # v2 TODO(jathan): Replace prefetch_related with select_related
-                "queryset": Prefix.objects.prefetch_related("site", "vrf__tenant", "tenant", "vlan", "role"),
+                "queryset": Prefix.objects.select_related("site", "vrf__tenant", "tenant", "vlan", "role"),
                 "filterset": PrefixFilterSet,
                 "table": PrefixTable,
                 "url": "ipam:prefix_list",
@@ -250,8 +239,7 @@ SEARCH_TYPES = OrderedDict(
         (
             "ipaddress",
             {
-                # v2 TODO(jathan): Replace prefetch_related with select_related
-                "queryset": IPAddress.objects.prefetch_related("vrf__tenant", "tenant"),
+                "queryset": IPAddress.objects.select_related("vrf__tenant", "tenant"),
                 "filterset": IPAddressFilterSet,
                 "table": IPAddressTable,
                 "url": "ipam:ipaddress_list",
@@ -260,8 +248,7 @@ SEARCH_TYPES = OrderedDict(
         (
             "vlan",
             {
-                # v2 TODO(jathan): Replace prefetch_related with select_related
-                "queryset": VLAN.objects.prefetch_related("site", "group", "tenant", "role"),
+                "queryset": VLAN.objects.select_related("site", "group", "tenant", "role"),
                 "filterset": VLANFilterSet,
                 "table": VLANTable,
                 "url": "ipam:vlan_list",
@@ -271,8 +258,7 @@ SEARCH_TYPES = OrderedDict(
         (
             "tenant",
             {
-                # v2 TODO(jathan): Replace prefetch_related with select_related
-                "queryset": Tenant.objects.prefetch_related("group"),
+                "queryset": Tenant.objects.select_related("group"),
                 "filterset": TenantFilterSet,
                 "table": TenantTable,
                 "url": "tenancy:tenant_list",
