@@ -34,6 +34,7 @@ from nautobot.dcim.filters import (
     SiteFilterSet,
 )
 from nautobot.extras.graphql.types import TagType  # noqa: F401
+from nautobot.extras.models import DynamicGroup
 
 
 class SiteType(gql_optimizer.OptimizedDjangoObjectType):
@@ -53,6 +54,11 @@ class DeviceType(gql_optimizer.OptimizedDjangoObjectType):
         filterset_class = DeviceFilterSet
         exclude = ["_name"]
 
+    dynamic_groups = graphene.List("nautobot.extras.graphql.types.DynamicGroupType")
+
+    def resolve_dynamic_groups(self, args):
+        return DynamicGroup.objects.get_for_object(self)
+
 
 class RackType(gql_optimizer.OptimizedDjangoObjectType):
     """Graphql Type Object for Rack model."""
@@ -62,6 +68,11 @@ class RackType(gql_optimizer.OptimizedDjangoObjectType):
         filterset_class = RackFilterSet
         exclude = ["images"]
 
+    dynamic_groups = graphene.List("nautobot.extras.graphql.types.DynamicGroupType")
+
+    def resolve_dynamic_groups(self, args):
+        return DynamicGroup.objects.get_for_object(self)
+
 
 class CableType(gql_optimizer.OptimizedDjangoObjectType):
     """Graphql Type Object for Cable model."""
