@@ -2,10 +2,12 @@ import logging
 
 from cacheops import invalidate_obj
 from django.contrib.contenttypes.models import ContentType
-from django.db.models.signals import post_save, pre_delete
+from django.core.exceptions import ValidationError
+from django.db.models.signals import m2m_changed, post_save, pre_delete
 from django.db import transaction
 from django.dispatch import receiver
 
+from .choices import InterfaceModeChoices
 from .models import (
     Cable,
     CablePath,
@@ -15,6 +17,7 @@ from .models import (
     Rack,
     RackGroup,
     VirtualChassis,
+    Interface,
 )
 
 
@@ -270,3 +273,19 @@ def nullify_connected_endpoints(instance, **kwargs):
             )
         else:
             cablepath.delete()
+
+
+#
+# Interface tagged VLAMs
+#
+
+
+@receiver(m2m_changed, sender=Interface.tagged_vlans.through)
+def prevent_adding_tagged_vlans_if_mode_not_set_to_tagged(sender, instance, action, **kwargs):
+    if action != "pre_add":
+        return
+
+    if instance.mode != InterfaceModeChoices.MODE_TAGGED:
+        raise ValidationError(
+            {"tagged_vlans": f"Mode must be set to {InterfaceModeChoices.MODE_TAGGED} when specifying tagged_vlans"}
+        )
