@@ -31,6 +31,7 @@ from nautobot.extras.api.fields import StatusSerializerField
 from nautobot.extras.choices import (
     CustomFieldFilterLogicChoices,
     CustomFieldTypeChoices,
+    JobExecutionType,
     JobResultStatusChoices,
     ObjectChangeActionChoices,
 )
@@ -72,6 +73,7 @@ from nautobot.tenancy.api.nested_serializers import (
 from nautobot.tenancy.models import Tenant, TenantGroup
 from nautobot.users.api.nested_serializers import NestedUserSerializer
 from nautobot.utilities.api import get_serializer_for_model
+from nautobot.utilities.deprecation import class_deprecated_in_favor_of
 from nautobot.utilities.utils import get_route_for_model, slugify_dashes_to_underscores
 from nautobot.virtualization.api.nested_serializers import (
     NestedClusterGroupSerializer,
@@ -79,7 +81,7 @@ from nautobot.virtualization.api.nested_serializers import (
 )
 from nautobot.virtualization.models import Cluster, ClusterGroup
 
-from .customfields import CustomFieldModelSerializer
+from .customfields import CustomFieldModelSerializerMixin
 from .fields import MultipleChoiceJSONField
 from .relationships import RelationshipModelSerializerMixin
 
@@ -152,7 +154,7 @@ class NotesSerializerMixin(BaseModelSerializer):
 
 
 class NautobotModelSerializer(
-    RelationshipModelSerializerMixin, CustomFieldModelSerializer, NotesSerializerMixin, ValidatedModelSerializer
+    RelationshipModelSerializerMixin, CustomFieldModelSerializerMixin, NotesSerializerMixin, ValidatedModelSerializer
 ):
     """Base class to use for serializers based on OrganizationalModel or PrimaryModel.
 
@@ -195,8 +197,7 @@ class TagSerializerField(NestedTagSerializer):
         return queryset.get_for_model(model)
 
 
-# 2.0 TODO should be TaggedModelSerializerMixin
-class TaggedObjectSerializer(BaseModelSerializer):
+class TaggedModelSerializerMixin(BaseModelSerializer):
     tags = TagSerializerField(many=True, required=False)
 
     def get_field_names(self, declared_fields, info):
@@ -234,6 +235,12 @@ class TaggedObjectSerializer(BaseModelSerializer):
         return instance
 
 
+# TODO: remove in 2.2
+@class_deprecated_in_favor_of(TaggedModelSerializerMixin)
+class TaggedObjectSerializer(TaggedModelSerializerMixin):
+    pass
+
+
 #
 # Computed Fields
 #
@@ -740,7 +747,7 @@ class ImageAttachmentSerializer(ValidatedModelSerializer):
 #
 
 
-class JobSerializer(NautobotModelSerializer, TaggedObjectSerializer):
+class JobSerializer(NautobotModelSerializer, TaggedModelSerializerMixin):
     url = serializers.HyperlinkedIdentityField(view_name="extras-api:job-detail")
 
     class Meta:
@@ -829,7 +836,7 @@ class JobRunResponseSerializer(serializers.Serializer):
 #
 
 
-class JobResultSerializer(CustomFieldModelSerializer, BaseModelSerializer):
+class JobResultSerializer(CustomFieldModelSerializerMixin, BaseModelSerializer):
     url = serializers.HyperlinkedIdentityField(view_name="extras-api:jobresult-detail")
     user = NestedUserSerializer(read_only=True)
     status = ChoiceField(choices=JobResultStatusChoices, read_only=True)
@@ -975,6 +982,44 @@ class JobInputSerializer(serializers.Serializer):
     task_queue = serializers.CharField(required=False, allow_blank=True)
 
 
+class JobMultiPartInputSerializer(serializers.Serializer):
+    """JobMultiPartInputSerializer is a "flattened" version of JobInputSerializer for use with multipart/form-data submissions which only accept key-value pairs"""
+
+    _commit = serializers.BooleanField(required=False, default=None)
+    _schedule_name = serializers.CharField(max_length=255, required=False)
+    _schedule_start_time = serializers.DateTimeField(format=None, required=False)
+    _schedule_interval = ChoiceField(choices=JobExecutionType, required=False)
+    _schedule_crontab = serializers.CharField(required=False, allow_blank=True)
+    _task_queue = serializers.CharField(required=False, allow_blank=True)
+
+    def validate(self, data):
+        data = super().validate(data)
+
+        if "_schedule_interval" in data and data["_schedule_interval"] != JobExecutionType.TYPE_IMMEDIATELY:
+            if "_schedule_name" not in data:
+                raise serializers.ValidationError({"_schedule_name": "Please provide a name for the job schedule."})
+
+            if ("_schedule_start_time" not in data and data["_schedule_interval"] != JobExecutionType.TYPE_CUSTOM) or (
+                "_schedule_start_time" in data and data["_schedule_start_time"] < ScheduledJob.earliest_possible_time()
+            ):
+                raise serializers.ValidationError(
+                    {
+                        "_schedule_start_time": "Please enter a valid date and time greater than or equal to the current date and time."
+                    }
+                )
+
+            if data["_schedule_interval"] == JobExecutionType.TYPE_CUSTOM:
+
+                if data.get("_schedule_crontab") is None:
+                    raise serializers.ValidationError({"_schedule_crontab": "Please enter a valid crontab."})
+                try:
+                    ScheduledJob.get_crontab(data["_schedule_crontab"])
+                except Exception as e:
+                    raise serializers.ValidationError({"_schedule_crontab": e})
+
+        return data
+
+
 class JobLogEntrySerializer(BaseModelSerializer):
     url = serializers.HyperlinkedIdentityField(view_name="extras-api:joblogentry-detail")
     display = serializers.SerializerMethodField()
@@ -1148,7 +1193,7 @@ class RelationshipAssociationSerializer(ValidatedModelSerializer):
 #
 
 
-class SecretSerializer(NautobotModelSerializer, TaggedObjectSerializer):
+class SecretSerializer(NautobotModelSerializer, TaggedModelSerializerMixin):
     """Serializer for `Secret` objects."""
 
     url = serializers.HyperlinkedIdentityField(view_name="extras-api:secret-detail")
