@@ -1,3 +1,4 @@
+from datetime import datetime
 import json
 from collections import OrderedDict
 
@@ -10,6 +11,7 @@ from django.core.serializers.json import DjangoJSONEncoder
 from django.core.exceptions import ValidationError
 from django.db import models
 from django.http import HttpResponse
+from django.utils.text import slugify
 from django.urls import reverse
 from graphene_django.settings import graphene_settings
 from graphql import get_default_backend
@@ -29,8 +31,9 @@ from nautobot.extras.choices import (
 )
 from nautobot.extras.constants import HTTP_CONTENT_TYPE_JSON
 from nautobot.extras.models import ChangeLoggedModel
+from nautobot.extras.models.mixins import NotesMixin
 from nautobot.extras.models.relationships import RelationshipModel
-from nautobot.extras.querysets import ConfigContextQuerySet
+from nautobot.extras.querysets import ConfigContextQuerySet, NotesQuerySet
 from nautobot.extras.utils import extras_features, FeatureQuery, image_upload
 from nautobot.utilities.utils import deepmerge, render_jinja2
 
@@ -61,7 +64,7 @@ class ConfigContextSchemaValidationMixin:
 
 
 @extras_features("graphql")
-class ConfigContext(BaseModel, ChangeLoggedModel, ConfigContextSchemaValidationMixin):
+class ConfigContext(BaseModel, ChangeLoggedModel, ConfigContextSchemaValidationMixin, NotesMixin):
     """
     A ConfigContext represents a set of arbitrary data available to any Device or VirtualMachine matching its assigned
     qualifiers (region, site, etc.). For example, the data stored in a ConfigContext assigned to site A and tenant B
@@ -99,8 +102,10 @@ class ConfigContext(BaseModel, ChangeLoggedModel, ConfigContextSchemaValidationM
     )
     regions = models.ManyToManyField(to="dcim.Region", related_name="+", blank=True)
     sites = models.ManyToManyField(to="dcim.Site", related_name="+", blank=True)
+    locations = models.ManyToManyField(to="dcim.Location", related_name="+", blank=True)
     roles = models.ManyToManyField(to="dcim.DeviceRole", related_name="+", blank=True)
     device_types = models.ManyToManyField(to="dcim.DeviceType", related_name="+", blank=True)
+    device_redundancy_groups = models.ManyToManyField(to="dcim.DeviceRedundancyGroup", related_name="+", blank=True)
     platforms = models.ManyToManyField(to="dcim.Platform", related_name="+", blank=True)
     cluster_groups = models.ManyToManyField(to="virtualization.ClusterGroup", related_name="+", blank=True)
     clusters = models.ManyToManyField(to="virtualization.Cluster", related_name="+", blank=True)
@@ -178,6 +183,9 @@ class ConfigContextModel(models.Model, ConfigContextSchemaValidationMixin):
 
     class Meta:
         abstract = True
+        indexes = [
+            models.Index(fields=("local_context_data_owner_content_type", "local_context_data_owner_object_id")),
+        ]
 
     def get_config_context(self):
         """
@@ -230,7 +238,7 @@ class ConfigContextSchema(OrganizationalModel):
     This model stores jsonschema documents where are used to optionally validate config context data payloads.
     """
 
-    name = models.CharField(max_length=200, unique=True)
+    name = models.CharField(max_length=200)
     description = models.CharField(max_length=200, blank=True)
     slug = AutoSlugField(populate_from="name", max_length=200, unique=None, db_index=True)
     data_schema = models.JSONField(
@@ -251,6 +259,11 @@ class ConfigContextSchema(OrganizationalModel):
         fk_field="owner_object_id",
     )
 
+    class Meta:
+        constraints = [
+            models.UniqueConstraint(fields=["name", "owner_content_type", "owner_object_id"], name="unique_name_owner"),
+        ]
+
     def __str__(self):
         if self.owner:
             return f"[{self.owner}] {self.name}"
@@ -289,7 +302,7 @@ class ConfigContextSchema(OrganizationalModel):
 
 
 @extras_features("graphql")
-class CustomLink(BaseModel, ChangeLoggedModel):
+class CustomLink(BaseModel, ChangeLoggedModel, NotesMixin):
     """
     A custom link to an external representation of a Nautobot object. The link text and URL fields accept Jinja2 template
     code to be rendered with an object as context.
@@ -343,7 +356,7 @@ class CustomLink(BaseModel, ChangeLoggedModel):
     "graphql",
     "relationships",
 )
-class ExportTemplate(BaseModel, ChangeLoggedModel, RelationshipModel):
+class ExportTemplate(BaseModel, ChangeLoggedModel, RelationshipModel, NotesMixin):
     # An ExportTemplate *may* be owned by another model, such as a GitRepository, or it may be un-owned
     owner_content_type = models.ForeignKey(
         to=ContentType,
@@ -388,7 +401,7 @@ class ExportTemplate(BaseModel, ChangeLoggedModel, RelationshipModel):
     def __str__(self):
         if self.owner:
             return f"[{self.owner}] {self.content_type}: {self.name}"
-        return "{}: {}".format(self.content_type, self.name)
+        return f"{self.content_type}: {self.name}"
 
     def render(self, queryset):
         """
@@ -411,12 +424,9 @@ class ExportTemplate(BaseModel, ChangeLoggedModel, RelationshipModel):
 
         # Build the response
         response = HttpResponse(output, content_type=mime_type)
-        filename = "{}{}{}".format(
-            settings.BRANDING_PREPENDED_FILENAME,
-            queryset.model._meta.verbose_name_plural,
-            ".{}".format(self.file_extension) if self.file_extension else "",
-        )
-        response["Content-Disposition"] = 'attachment; filename="{}"'.format(filename)
+        extension = f".{self.file_extension}" if self.file_extension else ""
+        filename = f"{settings.BRANDING_PREPENDED_FILENAME}{queryset.model._meta.verbose_name_plural}{extension}"
+        response["Content-Disposition"] = f'attachment; filename="{filename}"'
 
         return response
 
@@ -515,7 +525,7 @@ class FileProxy(BaseModel):
 
 
 @extras_features("graphql")
-class GraphQLQuery(BaseModel, ChangeLoggedModel):
+class GraphQLQuery(BaseModel, ChangeLoggedModel, NotesMixin):
     name = models.CharField(max_length=100, unique=True)
     slug = AutoSlugField(populate_from="name")
     query = models.TextField()
@@ -636,13 +646,55 @@ class ImageAttachment(BaseModel):
             return None
 
 
+#
+# Notes
+#
+
+
+@extras_features("graphql", "webhooks")
+class Note(BaseModel, ChangeLoggedModel):
+    """
+    Notes allow anyone with proper permissions to add a note to an object.
+    """
+
+    assigned_object_type = models.ForeignKey(to=ContentType, on_delete=models.CASCADE)
+    assigned_object_id = models.UUIDField(db_index=True)
+    assigned_object = GenericForeignKey(ct_field="assigned_object_type", fk_field="assigned_object_id")
+    user = models.ForeignKey(
+        to=settings.AUTH_USER_MODEL,
+        on_delete=models.SET_NULL,
+        related_name="note",
+        blank=True,
+        null=True,
+    )
+    user_name = models.CharField(max_length=150, editable=False)
+
+    slug = AutoSlugField(populate_from="assigned_object")
+    note = models.TextField()
+    objects = NotesQuerySet.as_manager()
+
+    class Meta:
+        ordering = ["created"]
+
+    def slugify_function(self, content):
+        return slugify(f"{str(content)[:50]}-{datetime.now().isoformat()}")
+
+    def __str__(self):
+        return str(self.slug)
+
+    def save(self, *args, **kwargs):
+        # Record the user's name as static strings
+        self.user_name = self.user.username if self.user else "Undefined"
+        return super().save(*args, **kwargs)
+
+
 #
 # Webhooks
 #
 
 
 @extras_features("graphql")
-class Webhook(BaseModel, ChangeLoggedModel):
+class Webhook(BaseModel, ChangeLoggedModel, NotesMixin):
     """
     A Webhook defines a request that will be sent to a remote application when an object is created, updated, and/or
     delete in Nautobot. The request will contain a representation of the object, which the remote application can act on.
