@@ -7,12 +7,25 @@ from django.urls import reverse
 
 from nautobot.dcim.choices import PortTypeChoices
 from nautobot.dcim.filters import DeviceFilterSet
-from nautobot.dcim.forms import DeviceForm, DeviceFilterForm
-from nautobot.dcim.models import Device, DeviceRole, DeviceType, FrontPort, Manufacturer, RearPort, Site
+from nautobot.dcim.forms import DeviceFilterForm, DeviceForm
+from nautobot.dcim.models import (
+    Device,
+    DeviceRole,
+    DeviceType,
+    FrontPort,
+    Location,
+    LocationType,
+    Manufacturer,
+    RearPort,
+    Region,
+    Site,
+)
 from nautobot.extras.choices import DynamicGroupOperatorChoices
-from nautobot.extras.models import DynamicGroup, DynamicGroupMembership, Status
 from nautobot.extras.filters import DynamicGroupFilterSet, DynamicGroupMembershipFilterSet
+from nautobot.extras.models import DynamicGroup, DynamicGroupMembership, Status
 from nautobot.ipam.models import Prefix
+from nautobot.utilities.forms.fields import MultiValueCharField
+from nautobot.utilities.forms.widgets import MultiValueCharInput
 from nautobot.utilities.testing import TestCase
 
 
@@ -121,6 +134,13 @@ class DynamicGroupTestBase(TestCase):
                 filter={"name": ["bogus"]},
                 content_type=cls.device_ct,
             ),
+            DynamicGroup.objects.create(
+                name="MultiValueCharFilter",
+                slug="multivaluecharfilter",
+                description="A group with a multivaluechar filter",
+                filter={"name": ["device-1", "device-2", "device-3"]},
+                content_type=cls.device_ct,
+            ),
         ]
 
         cls.parent = cls.groups[0]
@@ -238,6 +258,71 @@ class DynamicGroupModelTest(DynamicGroupTestBase):
         self.assertIn(device1, group.members)
         self.assertNotIn(device2, group.members)
 
+    def test_members_tree_nodes(self):
+        """
+        Test `DynamicGroup.members` when filtering on tree nodes like `Location`.
+        """
+        # Grab some values we'll used to setup the test case.
+        device1 = self.devices[0]
+        device2 = self.devices[1]
+        site = device1.site
+        status = Status.objects.get(slug="active")
+
+        # Create two LocationTypes (My Region > My Site)
+        loc_type_region = LocationType.objects.create(name="My Region", slug="my-region")
+        loc_type_region.content_types.add(self.device_ct)
+        loc_type_site = LocationType.objects.create(name="My Site", slug="my-site", parent=loc_type_region)
+        loc_type_site.content_types.add(self.device_ct)
+
+        loc_region = Location.objects.create(name="Location A", location_type=loc_type_region, site=site, status=status)
+        loc_site = Location.objects.create(
+            name="Location B", location_type=loc_type_site, parent=loc_region, status=status
+        )
+
+        # Add Location A to device1
+        device1.location = loc_region
+        device1.validated_save()
+
+        # Add Location B to device2
+        device2.site = device1.site
+        device2.location = loc_site
+        device2.validated_save()
+
+        expected = sorted([device1.name, device2.name])
+
+        # Create the Dynamic Group filtering on Location A
+        group = DynamicGroup.objects.create(
+            name="Devices Location",
+            slug="devices-location",
+            content_type=self.device_ct,
+            filter={"location": ["location-a"]},
+        )
+
+        # We are expecting that the group members here should be nested results from any devices
+        # that have a Location whose parent is "Location A".
+        self.assertEqual(
+            sorted(m.name for m in group.members),
+            expected,
+        )
+
+        # Now also test that an advancted (nested) dynamic group, also reports
+        # the same number of members.
+        parent_group = DynamicGroup.objects.create(
+            name="Parent of Devices Location",
+            slug="parent-devices-location",
+            content_type=self.device_ct,
+            filter={},
+        )
+        parent_group.add_child(
+            child=group,
+            operator=DynamicGroupOperatorChoices.OPERATOR_INTERSECTION,
+            weight=10,
+        )
+        self.assertEqual(
+            sorted(m.name for m in parent_group.members),
+            expected,
+        )
+
     def test_count(self):
         """Test `DynamicGroup.count`."""
         expected = {
@@ -327,6 +412,9 @@ class DynamicGroupModelTest(DynamicGroupTestBase):
         self.assertNotEqual(fields, {})
         self.assertNotIn("q", fields)
         self.assertIn("name", fields)
+        # See if a CharField is properly converted to a MultiValueCharField In DynamicGroupEditForm.
+        self.assertIsInstance(fields["name"], MultiValueCharField)
+        self.assertIsInstance(fields["name"].widget, MultiValueCharInput)
 
     def test_map_filter_fields_skip_missing(self):
         """
@@ -443,15 +531,12 @@ class DynamicGroupModelTest(DynamicGroupTestBase):
     def test_get_initial(self):
         """Test `DynamicGroup.get_initial()`."""
         group1 = self.first_child  # Filter has `site`
-        group2 = self.invalid_filter  # Filter has `name`
-
-        # Test that a CharField (e.g. `name`) gets flattened. We use group2 for this.
-        initial = group2.get_initial()
-        expected = {"name": "bogus"}
-        self.assertEqual(initial, expected)
-
-        # Otherwise, it just passes through the filter.
         self.assertEqual(group1.get_initial(), group1.filter)
+        # Test if MultiValueCharField is properly pre-populated
+        group2 = self.groups[6]  # Filter has `name`
+        initial = group2.get_initial()
+        expected = {"name": ["device-1", "device-2", "device-3"]}
+        self.assertEqual(initial, expected)
 
     def test_set_filter(self):
         """Test `DynamicGroup.set_filter()`."""
@@ -537,7 +622,7 @@ class DynamicGroupModelTest(DynamicGroupTestBase):
         self.assertQuerySetEqual(group_qs, device_qs)
 
         # Now do a non-multi-value filter.
-        # TODO(jathan): If we ever make "serial" a multi-value filter, this will need to be revised.
+        # 2.0 TODO(jathan): When "serial" becomes a multi-value filter, this will need to be revised or removed.
         solo_field = fs.filters["serial"]
         solo_value = "abc123"
         solo_query = group.generate_query_for_filter(filter_field=solo_field, value=solo_value)
@@ -545,6 +630,22 @@ class DynamicGroupModelTest(DynamicGroupTestBase):
         serial_qs = Device.objects.filter(serial__iexact=solo_value)
         self.assertQuerySetEqual(solo_qs, serial_qs)
 
+        # Test that a nested field_name w/ `generate_query` works as expected. This is explicitly to
+        # test a regression w/ nested slug-related values such as `DeviceFilterSet.region` which
+        # filters on `site__region`.
+        parent_region = Region.objects.filter(children__isnull=False).first()
+        nested_value = [parent_region.slug]
+        group.set_filter({"region": nested_value})
+        group.validated_save()
+
+        # We are making sure the filterset generated from the slug as an argument results in the same
+        # filtered queryset, and more importantly that the nested filter expression `site__region`
+        # is automatically used to get the related model name without failing.
+        nested_query = group.generate_query_for_filter(filter_field=fs.filters["region"], value=nested_value)
+        nested_qs = queryset.filter(nested_query)
+        region_qs = Device.objects.filter(site__region__slug__in=nested_value)
+        self.assertQuerySetEqual(nested_qs, region_qs)
+
     def test_generate_query_for_group(self):
         """Test `DynamicGroup.generate_query_for_group()`."""
         group = self.parent
@@ -813,7 +914,7 @@ class DynamicGroupFilterTest(DynamicGroupTestBase):
 
     def test_content_type(self):
         params = {"content_type": ["dcim.device", "virtualization.virtualmachine"]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 6)
+        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 7)
 
     def test_search(self):
         tests = {
@@ -821,8 +922,8 @@ class DynamicGroupFilterTest(DynamicGroupTestBase):
             "Invalid Filter": 1,  # name
             "invalid-filter": 1,  # slug
             "A group with a non-matching filter": 1,  # description
-            "dcim": 6,  # content_type__app_label
-            "device": 6,  # content_type__model
+            "dcim": 7,  # content_type__app_label
+            "device": 7,  # content_type__model
         }
         for value, cnt in tests.items():
             params = {"q": value}
