@@ -139,11 +139,11 @@ class JobHookFormTestCase(TestCase):
 
         self.assertEqual(JobHook.objects.filter(name=self.job_hooks_data[3]["name"]).count(), 0)
         self.assertIn("type_create", error_msg)
-        self.assertEquals(
+        self.assertEqual(
             error_msg["type_create"][0]["message"],
             "A job hook already exists for create on dcim | device type to job TestJobHookReceiverLog",
         )
-        self.assertEquals(
+        self.assertEqual(
             error_msg["type_update"][0]["message"],
             "A job hook already exists for update on dcim | device type to job TestJobHookReceiverLog",
         )
@@ -188,11 +188,7 @@ class NoteModelBulkEditFormMixinTestCase(TestCase):
 
     @classmethod
     def setUpTestData(cls):
-        active = Status.objects.get(slug="active")
-        cls.sites = [
-            dcim_models.Site.objects.create(name="Site 1", slug="site-1", status=active),
-            dcim_models.Site.objects.create(name="Site 2", slug="site-2", status=active),
-        ]
+        cls.sites = dcim_models.Site.objects.all()[:2]
         cls.user = User.objects.create(username="formuser1")
 
     def test_note_bulk_edit(self):
@@ -221,7 +217,7 @@ class RelationshipModelFormTestCase(TestCase):
 
     @classmethod
     def setUpTestData(cls):
-        cls.site = dcim_models.Site.objects.create(name="Site 1", slug="site-1")
+        cls.site = dcim_models.Site.objects.first()
         cls.manufacturer = dcim_models.Manufacturer.objects.create(name="Manufacturer 1", slug="manufacturer-1")
         cls.device_type = dcim_models.DeviceType.objects.create(model="Device Type 1", manufacturer=cls.manufacturer)
         cls.device_role = dcim_models.DeviceRole.objects.create(name="Device Role 1", slug="device-role-1")
@@ -672,10 +668,7 @@ class RelationshipModelBulkEditFormMixinTestCase(TestCase):
     @classmethod
     def setUpTestData(cls):
         active = Status.objects.get(slug="active")
-        cls.sites = [
-            dcim_models.Site.objects.create(name="Site 1", slug="site-1", status=active),
-            dcim_models.Site.objects.create(name="Site 2", slug="site-2", status=active),
-        ]
+        cls.sites = dcim_models.Site.objects.all()[:2]
         cls.ipaddresses = [
             ipam_models.IPAddress.objects.create(address="10.1.1.1/24", status=active),
             ipam_models.IPAddress.objects.create(address="10.2.2.2/24", status=active),
@@ -994,11 +987,11 @@ class WebhookFormTestCase(TestCase):
 
         self.assertEqual(Webhook.objects.filter(name=self.webhooks_data[2]["name"]).count(), 0)
         self.assertIn("type_create", error_msg)
-        self.assertEquals(
+        self.assertEqual(
             error_msg["type_create"][0]["message"],
             "A webhook already exists for create on dcim | console port to URL http://example.com/test",
         )
-        self.assertEquals(
+        self.assertEqual(
             error_msg["type_update"][0]["message"],
             "A webhook already exists for update on dcim | console port to URL http://example.com/test",
         )
@@ -1036,7 +1029,7 @@ class DeprecatedAliasesTestCase(TestCase):
                     # Ensure that warnings are always triggered
                     warnings.simplefilter("always")
 
-                    class MyForm(deprecated_form_class):
+                    class MyForm(deprecated_form_class):  # pylint: disable=unused-variable
                         pass
 
                     self.assertEqual(len(warn_list), 1)
@@ -1051,7 +1044,7 @@ class DeprecatedAliasesTestCase(TestCase):
                     # Ensure that warnings are always triggered
                     warnings.simplefilter("always")
 
-                    class MyBetterForm(replacement_form_class):
+                    class MyBetterForm(replacement_form_class):  # pylint: disable=unused-variable
                         pass
 
                     self.assertEqual(len(warn_list), 0)
@@ -1082,6 +1075,8 @@ class JobEditFormTestCase(TestCase):
             "time_limit": 650,
             "has_sensitive_variables": True,
             "has_sensitive_variables_override": True,
+            "task_queues": [],
+            "task_queues_override": True,
         }
         form = JobEditForm(data=form_data)
 
