@@ -270,10 +270,13 @@ class ConfigContextSchemaObjectValidationView(generic.ObjectView):
 
         # Device table
         device_table = DeviceTable(
-            # v2 TODO(jathan): Replace prefetch_related with select_related
-            data=instance.device_set.prefetch_related(
-                "tenant", "site", "rack", "device_type", "device_role", "primary_ip"
-            ),
+            data=instance.device_set.select_related(
+                "tenant",
+                "site",
+                "rack",
+                "device_type",
+                "device_role",
+            ).prefetch_related("primary_ip"),
             orderable=False,
             extra_columns=[
                 (
@@ -291,8 +294,11 @@ class ConfigContextSchemaObjectValidationView(generic.ObjectView):
 
         # Virtual machine table
         virtual_machine_table = VirtualMachineTable(
-            # v2 TODO(jathan): Replace prefetch_related with select_related
-            data=instance.virtualmachine_set.prefetch_related("cluster", "role", "tenant", "primary_ip"),
+            data=instance.virtualmachine_set.select_related(
+                "cluster",
+                "role",
+                "tenant",
+            ).prefetch_related("primary_ip"),
             orderable=False,
             extra_columns=[
                 (
@@ -846,8 +852,7 @@ class GitRepositoryBulkImportView(generic.BulkImportView):
 
 
 class GitRepositoryBulkEditView(generic.BulkEditView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = GitRepository.objects.prefetch_related("secrets_group")
+    queryset = GitRepository.objects.select_related("secrets_group")
     filterset = filters.GitRepositoryFilterSet
     table = tables.GitRepositoryBulkTable
     form = forms.GitRepositoryBulkEditForm
@@ -1033,7 +1038,6 @@ class JobListView(generic.ObjectListView):
             queryset = queryset.filter(installed=True)
         if "is_job_hook_receiver" not in request.GET:
             queryset = queryset.filter(is_job_hook_receiver=False)
-        # v2 TODO(jathan): Replace prefetch_related with select_related
         queryset = queryset.prefetch_related("results")
         return queryset
 
@@ -1477,8 +1481,7 @@ class JobResultListView(generic.ObjectListView):
     List JobResults
     """
 
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = JobResult.objects.prefetch_related("job_model", "logs", "obj_type", "user")
+    queryset = JobResult.objects.select_related("job_model", "obj_type", "user").prefetch_related("logs")
     filterset = filters.JobResultFilterSet
     filterset_form = forms.JobResultFilterForm
     table = tables.JobResultTable
@@ -1634,10 +1637,9 @@ class ObjectChangeLogView(View):
 
         # Gather all changes for this object (and its related objects)
         content_type = ContentType.objects.get_for_model(model)
-        # v2 TODO(jathan): Replace prefetch_related with select_related
         objectchanges = (
             ObjectChange.objects.restrict(request.user, "view")
-            .prefetch_related("user", "changed_object_type")
+            .select_related("user", "changed_object_type")
             .filter(
                 Q(changed_object_type=content_type, changed_object_id=obj.pk)
                 | Q(related_object_type=content_type, related_object_id=obj.pk)
@@ -2059,8 +2061,9 @@ class TagView(generic.ObjectView):
     queryset = Tag.objects.all()
 
     def get_extra_context(self, request, instance):
-        # v2 TODO(jathan): Replace prefetch_related with select_related
-        tagged_items = TaggedItem.objects.filter(tag=instance).prefetch_related("content_type", "content_object")
+        tagged_items = (
+            TaggedItem.objects.filter(tag=instance).select_related("content_type").prefetch_related("content_object")
+        )
 
         # Generate a table of all items tagged with this Tag
         items_table = tables.TaggedItemTable(tagged_items)
